@@ -181,6 +181,14 @@ class ldap extends DS {
 		 * specifies deref behavior for each ldap_search operation. */
 		ldap_set_option($resource,LDAP_OPT_REFERRALS,0);
 
+		/* Enabling manageDsaIt to be able to browse through glued entries
+		 * 2.16.840.1.113730.3.4.2 :  "ManageDsaIT Control" "RFC 3296" "The client may provide
+		 * the ManageDsaIT control with an operation to indicate that the operation is intended
+		 * to manage objects within the DSA (server) Information Tree. The control causes
+		 * Directory-specific entries (DSEs), regardless of type, to be treated as normal entries
+		 * allowing clients to interrogate and update these entries using LDAP operations." */
+		ldap_set_option($resource,LDAP_OPT_SERVER_CONTROLS,array(array('oid'=>'2.16.840.1.113730.3.4.2')));
+
 		# Try to fire up TLS is specified in the config
 		if ($this->isTLSEnabled())
 			$this->startTLS($resource);
@@ -251,7 +259,7 @@ class ldap extends DS {
 			else
 				$userDN = $this->getLoginID($user,'login');
 
-			if (! $userDN && $this->getValue('login','fallback_dn'))
+			if (! $userDN && $this->getValue('login','fallback_dn') && strpos($user, '='))
 				$userDN = $user;
 
 			if (! $userDN)
@@ -1116,15 +1124,14 @@ class ldap extends DS {
 
 		if (is_array($dn)) {
 			$a = array();
-			foreach ($dn as $key => $rdn)
-				$a[$key] = preg_replace_callback('/\\\([0-9A-Fa-f]{2})/',
-					function ($matches) { return chr(hexdec($matches[1])); }, $rdn);
-
+			foreach ($dn as $key => $rdn) {
+				$a[$key] = preg_replace_callback('/\\\([0-9A-Fa-f]{2})/', function($m) { return chr(hexdec('${m[1]}')); }, $rdn);
+			}
 			return $a;
 
-		} else
-			return preg_replace_callback('/\\\([0-9A-Fa-f]{2})/',
-					function ($matches) { return chr(hexdec($matches[1])); }, $dn);
+		} else {
+			return preg_replace_callback('/\\\([0-9A-Fa-f]{2})/', function($m) { return chr(hexdec('${m[1]}')); }, $dn);
+		}
 	}
 
 	public function getRootDSE($method=null) {
